@@ -1,12 +1,9 @@
-# Copyright (c) 2019, Matt Layman and contributors
-
 from io import StringIO
 import itertools
 import re
 import sys
 
 from tap.directive import Directive
-from tap.i18n import _
 from tap.line import Bail, Diagnostic, Plan, Result, Unknown, Version
 
 try:
@@ -60,9 +57,6 @@ class Parser(object):
 
     TAP_MINIMUM_DECLARED_VERSION = 13
 
-    def __init__(self):
-        self._try_peeking = False
-
     def parse_file(self, filename):
         """Parse a TAP file to an iterable of tap.line.Line objects.
 
@@ -103,7 +97,6 @@ class Parser(object):
             if first_parsed.category == "version" and first_parsed.version >= 13:
                 if ENABLE_VERSION_13:
                     fh_new = peekable(itertools.chain([first_line], fh))
-                    self._try_peeking = True
                 else:  # pragma no cover
                     print(
                         """
@@ -157,7 +150,7 @@ WARNING: Optional imports not found, TAP 13 output will be
         """Parse a matching result line into a result instance."""
         peek_match = None
         try:
-            if fh is not None and self._try_peeking:
+            if fh is not None and ENABLE_VERSION_13 and isinstance(fh, peekable):
                 peek_match = self.yaml_block_start.match(fh.peek())
         except StopIteration:
             pass
@@ -185,7 +178,8 @@ WARNING: Optional imports not found, TAP 13 output will be
         try:
             next(fh)
             while indent_match.match(fh.peek()):
-                raw_yaml.append(next(fh).replace(indent, "", 1))
+                yaml_line = next(fh).replace(indent, "", 1)
+                raw_yaml.append(yaml_line.rstrip("\n"))
                 # check for the end and stop adding yaml if encountered
                 if self.yaml_block_end.match(fh.peek()):
                     next(fh)
@@ -198,6 +192,6 @@ WARNING: Optional imports not found, TAP 13 output will be
         version = int(match.group("version"))
         if version < self.TAP_MINIMUM_DECLARED_VERSION:
             raise ValueError(
-                _("It is an error to explicitly specify any version lower than 13.")
+                "It is an error to explicitly specify any version lower than 13."
             )
         return Version(version)
